@@ -27,7 +27,7 @@ from .settings import (
 )
 from .utils import (
     MAIN_DEVICE_PARAMS, MAIN_STATION_PARAMS, RIGHT_PARAMS_NAMES,
-    USELESS_COLS, add_progress_bar, debugit,
+    USELESS_COLS, add_progress_bar,
     parse_checkinfo, prep_df, prep_dicts, timeit, to_date,
     unpack_cols,
 )
@@ -89,11 +89,12 @@ class CityAirRequest:
     def _device_value_types(self):
         value_types_data = self._make_request(DEVICES_URL,
                                               "PacketsValueTypes")
-        value_types =  dict(zip([(data.get('ValueType')) for data in value_types_data],
-                        [data.get('TypeName') for data in value_types_data]))
+        value_types = dict(
+                zip([(data.get('ValueType')) for data in value_types_data],
+                    [data.get('TypeName') for data in value_types_data]))
         # adding "_" to not unique value type names
         name_counts = Counter(value_types.values())
-        for id, name in reversed(value_types.items()):
+        for id, name in value_types.items():
             current_count = name_counts[name]
             if current_count > 1:
                 value_types[id] = name + (current_count - 1) * "_"
@@ -147,7 +148,6 @@ class CityAirRequest:
                     res[device] = [station.copy()]
         return res
 
-    @debugit
     @timeit
     def _make_request(self, method_url: str, *keys: str,
                       silent: bool = True, **kwargs: object):
@@ -197,8 +197,7 @@ class CityAirRequest:
             return [response_data[key] for key in keys]
 
     def get_devices(self, format: str = 'list', include_offline: bool = True,
-                    include_children: bool = False,
-                    time=False, debug=False) \
+                    include_children: bool = False) \
             -> Union[List[str], pd.DataFrame, List[dict]]:
         """
         Provides devices information in various formats
@@ -216,13 +215,8 @@ class CityAirRequest:
             whether to include offline devices to the output
         include_children : bool, default False
             whether to include info of child devices to the output
-        time: bool, default False
-            whether to print how long it took to gather data
-        debug: bool, default False
-            whether to print raw request and response data
         -------"""
-        devices_data = self._make_request(DEVICES_URL, "Devices",
-                                          time=time, debug=debug)
+        devices_data = self._make_request(DEVICES_URL, "Devices")
         df = pd.DataFrame.from_records(devices_data)
         if format == 'raw':
             return df
@@ -266,8 +260,7 @@ class CityAirRequest:
     def get_device_data(self, serial_number: str, start_date=None,
                         finish_date=None, last_packet_id=None,
                         take_count: int = 500, all_cols=False,
-                        format: str = 'df', verbose=True,
-                        time=False, debug=False) \
+                        format: str = 'df', verbose=True) \
             -> Union[pd.DataFrame, Dict[str, pd.DataFrame]]:
         """
         Provides data from the selected device
@@ -297,10 +290,6 @@ class CityAirRequest:
                        data of the device
         verbose: bool, default True:
             whether to show progress bar
-        time: bool, default False
-            whether to print how long it took to gather data
-        debug: bool, default False
-            whether to print raw request and response data
         -------"""
 
         device_id = self._device_by_serial.get(serial_number)
@@ -321,8 +310,7 @@ class CityAirRequest:
             filter_['FilterType'] = 3
             filter_['Skip'] = 0
         packets = self._make_request(DEVICES_PACKETS_URL, 'Packets',
-                                     Filter=filter_, time=time, silent=False,
-                                     debug=debug)
+                                     Filter=filter_, silent=False)
         df = pd.DataFrame.from_records(packets)
 
         df = unpack_cols(df, ['ServiceData'])
@@ -387,9 +375,8 @@ class CityAirRequest:
                     f"Unknown option of format argument: {format}. Available "
                     f"formats are: 'df', 'dict'")
 
-    def get_stations(self, format: str = 'list', include_offline: bool = True,
-                     time=False, debug=False) \
-            -> Union[List[str], pd.DataFrame, List[dict]]:
+    def get_stations(self, format: str = 'list', include_offline: bool =
+    True) -> Union[List[str], pd.DataFrame, List[dict]]:
         """
         Provides devices information in various formats
 
@@ -404,15 +391,10 @@ class CityAirRequest:
             server, other params are ignored
         include_offline: bool, default True
            whether to include offline devices to the output
-        time: bool, default False
-           whether to print how long it took to gather data
-        debug: bool, default False
-           whether to print raw request and response data
         -------"""
         locations_data, stations_data, devices_data = self._make_request(
                 STATIONS_URL, "Locations",
-                "MoItems", "Devices",
-                time=time, debug=debug)
+                "MoItems", "Devices")
         locations = dict(
                 zip([(data.get('LocationId')) for data in locations_data],
                     [data.get('Name') for data in locations_data]))
@@ -459,7 +441,7 @@ class CityAirRequest:
                          finish_date=datetime.datetime.now(),
                          take_count: int = 1000,
                          period: Period = Period.TWENTY_MINS, verbose=True,
-                         time=False, debug=False) -> pd.DataFrame:
+                         time=False) -> pd.DataFrame:
         """
         Provides data from the selected station
         Parameters
@@ -474,10 +456,6 @@ class CityAirRequest:
             period could be five mins, twenty mins, hour, day
         verbose: bool, default True:
             whether to show progress bar
-        time: bool, default False
-            whether to print how long it took to gather data
-        debug: bool, default False
-            whether to print raw request and response data
         -------"""
         filter_ = {'TakeCount'   : take_count,
                    'MoId'        : station_id,
@@ -492,18 +470,16 @@ class CityAirRequest:
             filter_['FilterType'] = 3
             filter_['SkipFromLast'] = 0
         packets = self._make_request(STATIONS_PACKETS_URL, 'Packets',
-                                     Filter=filter_, time=time, debug=debug,
-                                     silent=False)
+                                     Filter=filter_, silent=False)
         df = pd.DataFrame.from_records(packets)
         records = []
-        for packets in df['DataJson']:
-            packets = json.loads(packets)
+        for packets in df['Data']:
             records.append(dict(zip(
-                    [self._stations_value_types.get(packet['Id'], 'undefined')
+                    [self._stations_value_types.get(packet['VT'], 'undefined')
                      for packet in packets],
-                    [packet['Sum'] / packet['Cnt'] for packet in packets])))
+                    [packet['V'] for packet in packets])))
         df = df.assign(**pd.DataFrame.from_records(records))
-        df = prep_df(df.drop(['DataJson'], axis=1), index_col='date')
+        df = prep_df(df.drop(['Data'], axis=1), index_col='date')
         return df
 
     def get_locations(self) -> List[dict]:
