@@ -1,13 +1,11 @@
 import datetime
-import getpass
 import logging
-import os
 import re
 import sys
 import time
 from collections import defaultdict
 from functools import wraps
-from typing import List, Tuple, Union, Optional
+from typing import List, Optional, Union
 
 import pandas as pd
 import progressbar
@@ -118,8 +116,6 @@ def add_progress_bar(method):
                     start_date = res.index[-1]
                 else:
                     for serial, df in data.items():
-                        print(res[serial].columns)
-                        print(df.columns)
                         res[serial] = pd.concat([res[serial], df], sort=False)
                     start_date = max([res[key].index[-1] for key in res])
             except EmptyDataException:
@@ -249,39 +245,15 @@ def timeit(method):
     Decorator to print time elapsed
 
     """
-
     @wraps(method)
     def timed(*args, **kwargs):
-        to_time = kwargs.pop('time', False)
         ts = time.time()
         result = method(*args, **kwargs)
         te = time.time()
-        if to_time:
-            print(f"{te - ts:.2f} seconds took to {method.__name__} of size"
+
+        logging.debug(f"{te - ts:.2f} seconds took to {method.__name__} of size"
                   f"{sys.getsizeof(result) / 1000: .2f} KB\nargs were"
                   f" {', '.join(map(str, args[1:]))}\nkwargs were: {kwargs}")
         return result
-
     return timed
 
-
-def debugit(method):
-    """
-    Decorator to print raw response and request data
-
-    """
-
-    @wraps(method)
-    def print_request_response(*args, **kwargs):
-        to_debug = kwargs.pop('debug', False)
-        obj = args[0]
-        body = {"Token": getattr(obj, 'token'), **kwargs}
-        url = f"{getattr(obj, 'host_url', None)}/{args[1]}"
-        if to_debug:
-            print(f"url: {url}\nrequest_body: {body}")
-        result = method(*args, **kwargs)
-        if to_debug:
-            print(f"response: {result}")
-        return result
-
-    return print_request_response
